# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Duplicate recorder name.
INVALIDPARAMETERVALUE_RECORDERNAMEREPEAT = 'InvalidParameterValue.RecorderNameRepeat'

# The number of resource recorders exceeds the limit.
LIMITEXCEEDED_RECORDEROVERAMOUNT = 'LimitExceeded.RecorderOverAmount'

# Recorder not found.
RESOURCENOTFOUND_RECORDERNOTFOUND = 'ResourceNotFound.RecorderNotFound'

# Resource not found.
RESOURCENOTFOUND_RESOURCENOTFOUND = 'ResourceNotFound.ResourceNotFound'
